@@ -376,9 +376,9 @@ class API:
         if not tmp["bool"]: print(tmp["Data"])
         return tmp["bool"]
     
-    def disconnect_from_voice(self, user_id: str) -> bool:
+    def disconnect_from_voice(self) -> bool:
         self.sending = True
-        self.__send({"Command": "Disconnect From Voice", "Value":user_id})
+        self.__send({"Command": "Disconnect From Voice", "Value":None})
         tmp = self.__wait_for_response()
         if not tmp["bool"]: print(tmp["Data"])
         return tmp["bool"]
